#
# spec file for package ghc-cmark
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name cmark
%if 0%{?suse_version} >= 1330
%define is_tumble 1
%endif
# is Leap 42.2+ or SLE12SP2+
%if 0%{?sle_version} >= 120200
%define is_sp2up 1
%endif
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.5.5
Release:        3.1
Summary:        Fast, accurate CommonMark (Markdown) parser and renderer
License:        BSD-3-Clause AND BSD-2-Clause AND MIT
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?is_tumble} || 0%{?is_sp2up}
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcmark)
%endif
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
%endif

%description
This package provides Haskell bindings for <https://github.com/jgm/cmark
libcmark>, the reference parser for <http://commonmark.org CommonMark>, a fully
specified variant of Markdown. It includes sources for libcmark (0.27.1) and
does not require prior installation of the C library.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
%if 0%{?is_tumble} || 0%{?is_sp2up}
Requires:       pkgconfig
Requires:       pkgconfig(libcmark)
%endif

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
%if 0%{?is_tumble} || 0%{?is_sp2up}
cabal-tweak-flag    pkgconfig   True
%endif

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc README.md changelog

%changelog
* Sun Feb  5 2017 psimons@suse.com
- Update to version 0.5.5 with cabal2obs.
* Tue Nov 22 2016 psimons@suse.com
- Update to version 0.5.4 with cabal2obs.
* Fri Jul 22 2016 psimons@suse.com
- Update to version 0.5.3.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.5.2.1 revision 0 with cabal2obs.
* Tue Jun 14 2016 mimi.vx@gmail.com
- use system libcmark on SLE12SP2+ and Leap:42.2
* Mon May 23 2016 mimi.vx@gmail.com
- update to 0.5.2.1
* Fri Apr 15 2016 mimi.vx@gmail.com
- use system libcmark on openSUSE:Tumbleweed
* Tue Mar 29 2016 mimi.vx@gmail.com
- update to 0.5.2
  * Add flag to allow building with an installed libcmark (Jens Petersen).
  * Updated to libcmark 0.25.2.
* Sun Jan 24 2016 mimi.vx@gmail.com
-  update to 0.5.1
  * Updated to libcmark 0.24.1.
* Sat Jan 23 2016 mimi.vx@gmail.com
- update to 0.5.0
  * Updated to libcmark 0.23.0.
  * API changes:
  + Added `OnEnter` and `OnExit` types.
  + In `NodeType`, `HRULE` is now `THEMATIC_BREAK`,
    `HTML` is `HTML_BLOCK`, `INLINE_HTML` is
    `HTML_INLINE`, `HEADER` is `HEADING`.  New
    constructors: `CUSTOM_INLINE`, `CUSTOM_BLOCK`.
* Mon Aug 31 2015 mimi.vx@gmail.com
- update to 0.4.1
  * Updated to libcmark 0.22.0
  * Bumped version bounds for HUnit.
* Fri Aug 21 2015 cfarrell@suse.com
- license update: BSD-3-Clause and BSD-2-Clause and MIT
* Tue Jul 28 2015 mimi.vx@gmail.com
- update to 0.4.0.1
  * API changes:
    + Added `commonmarkToLaTeX`, `nodeToLaTeX`, `optSafe`.
    + Changed type of `commonmarkToMan` and `nodeToMan`,
    adding `Maybe Int` param for width.
    + Changed type of `nodeToCommonMark`, changing the `Int` width
    parameter to a `Maybe Int`.
  * Updated to cmark 0.21 sources.
* Fri Jun 12 2015 mimi.vx@gmail.com
- update to 0.3.4
  * Updated to libcmark 0.20.0.
* Sun May 31 2015 mimi.vx@gmail.com
- initial commit
